# phidata

[![ Build Status ](https://github.com/phidatahq/phidata/actions/workflows/build-release.yml/badge.svg?branch=main)](https://github.com/phidatahq/phidata/actions/workflows/build-release.yml)

## Automate Data Engineering as Code.

---
